{% extends "header.html" %}
{% block title %}Results{% endblock %}
{% block content_root %}
<div class="jumbotron">
    <div class="container">
        <hr />
        <h1 class="text-center">Disaster Response Classification</h1>
        <p class="text-center">Classify message for disaster response support needed</p>
        <hr />
        <div class="row">
            <div class="col-lg-12 form-group-lg">
                <form action="/go" method="get">
                    <input type="text" class="form-control form-control-lg" name="query" placeholder="Enter a message to classify">
                    <div class="col-lg-offset-5">
                        <button type="submit" class="btn btn-lg btn-success">Classify Message</button>
                    </div>
                </form>
            </div>
        </div>
</div>
{% endblock %}
